
# Poleemploi Connector

> Thanks to the Job Offers API, you can access all the job offers available on the Pôle emploi website at any time and in real time.


🔗 https://www.pole-emploi.fr/

| Actions |
| ------- |
| [**Pull jobs**](docs/pull_jobs.md) |
